@@ -1,4 +1,4 @@
-/* Copyright (C) 1998, 1999 Free Software Foundation, Inc.
+/* Copyright (C) 1998, 1999, 2003, 2005 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -23,9 +23,6 @@
 #include <sysdep.h>
 #include <sys/syscall.h>
 
-extern int __syscall_getpmsg (int fildes, struct strbuf *ctlptr,
-			      struct strbuf *dataptr, int *bandp, int *flagsp);
-
 #ifdef __NR_getpmsg
 int
 getmsg (fildes, ctlptr, dataptr, flagsp)
@@ -37,5 +34,5 @@ getmsg (fildes, ctlptr, dataptr, flagsp)
   return INLINE_SYSCALL (getpmsg, 5, fildes, ctlptr, dataptr, NULL, flagsp);
 }
 #else
-# include <sysdeps/generic/getmsg.c>
+# include <streams/getmsg.c>
 #endif
